.. _lease-module:

=========
chi.lease
=========

The :mod:`chi.lease` module exposes both a functional interface and an
object-oriented interface for interacting with resource leases.

Functional interface
====================

.. automodule:: chi.lease
   :members:

Object-oriented interface
=========================

.. autoclass:: chi.lease.Lease
   :members:
